@@ -3,25 +3,32 @@
 This plugin is using the same API as the mobile app.
 """
 
-from livestreamer.plugin import Plugin
-from livestreamer.stream import HLSStream
-from livestreamer.utils import urlget, res_xml
-
 import re
 
+from livestreamer.plugin import Plugin
+from livestreamer.plugin.api import http, validate
+from livestreamer.stream import HLSStream
+
 API_BASE = "http://gox.gomexp.com/cgi-bin"
 API_URL_APP = API_BASE + "/app_api.cgi"
 API_URL_LIVE = API_BASE + "/gox_live.cgi"
 
+_url_re = re.compile("http(s)?://(www\.)?gomexp.com")
+
+_entries_schema = validate.Schema(
+    validate.xml_findall("./ENTRY/*/[@reftype='live'][@href]"),
+    [validate.get("href")]
+)
+
 
 class GOMeXP(Plugin):
     @classmethod
     def can_handle_url(self, url):
-        return re.match(r"http(s)?://(www\.)?gomexp.com", url)
+        return _url_re.match(url)
 
     def _get_live_cubeid(self):
-        res = urlget(API_URL_APP, params=dict(mode="get_live"))
-        root = res_xml(res)
+        res = http.get(API_URL_APP, params=dict(mode="get_live"))
+        root = http.xml(res)
         return root.findtext("./cube/cubeid")
 
     def _get_streams(self):
@@ -29,17 +36,14 @@ class GOMeXP(Plugin):
         if not cubeid:
             return
 
-        res = urlget(API_URL_LIVE, params=dict(cubeid=cubeid))
-        root = res_xml(res)
-
+        res = http.get(API_URL_LIVE, params=dict(cubeid=cubeid))
+        entries = http.xml(res, schema=_entries_schema)
         streams = {}
-        for entry in root.findall("./ENTRY/*/[@reftype='live'][@href]"):
-            url = entry.get("href")
-
+        for url in entries:
             try:
-                hls_streams = HLSStream.parse_variant_playlist(self.session,
-                                                               url)
-                streams.update(hls_streams)
+                streams.update(
+                    HLSStream.parse_variant_playlist(self.session, url)
+                )
             except IOError as err:
                 self.logger.error("Failed to open playlist: {0}", err)
 
